<template>
  <div class="content">
    <div class="el-card_top">
      <el-form :inline="true" :model="formInline">
        <el-form-item label="公司" prop="companyName">
          <CascaderCompany
            :value="formInline.companyIds"
            @changecom="companyChange"
            :placeholder="'请选择公司名称'"
          />
        </el-form-item>
      </el-form>
    </div>
    <div class="box-card">
      <div class="item">
        <div class="top">
          <p>
            <i class="el-icon-pie-chart"></i>
          </p>
          <h1>桥梁类型统计</h1>
        </div>

        <div class="item-charts">
          <div id="typeCharts" :style="{width: '100%', height: '100%'}"></div>
        </div>
      </div>
      <div class="item" style="margin: 0 10px">
        <div class="top">
          <p>
            <i class="el-icon-pie-chart"></i>
          </p>
          <h1>桥梁类别统计</h1>
        </div>

        <div class="item-charts">
          <div
            id="categoryCharts"
            :style="{width: '100%', height: '100%'}"
          ></div>
        </div>
      </div>
      <div class="item">
        <div class="top">
          <p>
            <i class="el-icon-pie-chart"></i>
          </p>
          <h1>上部结构比例清单</h1>
        </div>

        <div class="item-charts">
          <div
            id="structureCharts"
            :style="{width: '100%', height: '100%'}"
          ></div>
        </div>
      </div>
    </div>

    <div class="table-box">
      <div class="top" style="margin-top: 60px">
        <p>
          <i class="el-icon-pie-chart"></i>
        </p>
        <h1>桥梁类型统计</h1>
      </div>
      <el-button type="primary" class="botton">
        导出列表
      </el-button>
      <div class="table-box-main">
        <el-table :data="tableData" border style="width: 100%; height: 100%;">
          <el-table-column align="center" prop="name" label="上部结构类型">
          </el-table-column>
          <el-table-column align="center" prop="shapeTypeCount" label="数量(个)">
          </el-table-column>
          <el-table-column align="center" prop="length" label="单位总长(km)">
          </el-table-column>
        </el-table>
      </div>
    </div>
  </div>
</template>

<script>
import * as echarts from 'echarts'
import CascaderCompany from './components/CascaderCompany_.vue'
export default {
  name: 'BridgeStructureStatistics',
  components: {
    CascaderCompany
  },
  data() {
    return {
      formInline: {
        companyIds: ['1419863231459102720', '1430734631036129280'],
        companyName: '',
        roadSegmentName: ''
      },
      tableData: [],
      roadOptions: [] //选取路段
    }
  },
  mounted() {
    this.companyChange(['1419863231459102720', '1430734631036129280'])
  },
  methods: {
    companyChange(val) {
      this.formInline.companyIds = val
      let id = (val && val[val.length - 1]) || ''
      if (!id) return
      this.$http
        .get('${yhxt}/statisticalStatement/v1/findAllRoadIds?id=' + id)
        .then(res => {
          let ids = res.data.value.join(',') || id || ''
          if (!ids) {
            this.getTypeCharts([])
            this.tableData = []
          } else {
            this.load(ids)
          }
        })
    },
    load(roadSegmentId) {
      this.$http
        .post('${yhxt}/statisticalStatement/v1/countReportBridge', {
          roadSegmentId
        })
        .then(res => {
          //桥梁类型
          this.getTypeCharts(res.data)
          this.getCategoryCharts(res.data)
          this.getStructureCharts(res.data)
          this.tableData = res.data.bridgeShapeType
        })
    },
    // 桥梁类型
    getTypeCharts(data) {
      let chartDom = document.getElementById('typeCharts')
      let myChart = echarts.init(chartDom)
      data.bridgeType.forEach(item => {
        item['name'] = item['typeValue']
        item['value'] = item['typeCount']
      })
      let option = {
        tooltip: {
          trigger: 'item',
          formatter: a => {
            return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
          }
        },
        color: ['#56d0a3', '#596d90', '#eab61a', '#6a5cf1', '#578bf1'],
        legend: {
          icon: 'circle',
          orient: 'vertical',
          right: 80,
          top: 'center',
          bottom: 20,
          textStyle: {
            color: '#fff'
          }
        },
        title: {
          left: 'center',
          textStyle: {
            color: '#fff'
          }
        },
        series: [
          {
            type: 'pie',
            radius: ['40%', '60%'],
            center: ['40%', '50%'],
            data: data.bridgeType,
            label: {
              color: '#fff',
              formatter: a => {
                return `{percent|${a.percent}%}`
              },
              fontSize: 14,
              rich: {
                percent: {
                  fontSize: 15,
                  color: '#fff'
                }
              }
            },
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            }
          }
        ]
      }
      option && myChart.setOption(option)
    },
    // 桥梁类别
    getCategoryCharts(data) {
      let chartDom = document.getElementById('categoryCharts')
      let myChart = echarts.init(chartDom)
      data.category.forEach(item => {
        item['name'] = item['categoryValue']
        item['value'] = item['categoryCount']
      })
      let option = {
        tooltip: {
          trigger: 'item',
          formatter: a => {
            return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
          }
        },
        color: ['#56d0a3', '#596d90', '#eab61a', '#6a5cf1', '#578bf1'],
        legend: {
          icon: 'circle',
          orient: 'vertical',
          right: 80,
          top: 'center',
          bottom: 20,
          textStyle: {
            color: '#fff'
          }
        },
        title: {
          left: 'center',
          textStyle: {
            color: '#fff'
          }
        },
        series: [
          {
            type: 'pie',
            radius: ['40%', '60%'],
            center: ['40%', '50%'],
            data: data.category,
            label: {
              color: '#fff',
              formatter: a => {
                return `{percent|${a.percent}%}`
              },
              fontSize: 14,
              rich: {
                percent: {
                  fontSize: 15,
                  color: '#fff'
                }
              }
            },
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            }
          }
        ]
      }
      option && myChart.setOption(option)
    },
    // 上部结构比例清单
    getStructureCharts(data) {
      let chartDom = document.getElementById('structureCharts')
      let myChart = echarts.init(chartDom)
      data.bridgeShapeType.forEach(item => {
        item['name'] = item['shapeTypeValue']
        item['value'] = item['shapeTypeCount']
      })
      let option = {
        tooltip: {
          trigger: 'item',
          formatter: a => {
            return `${a.marker} ${a.data.name} ${a.data.value}个 ${a.percent}%`
          }
        },
        color: ['#56d0a3', '#596d90', '#eab61a', '#6a5cf1', '#578bf1'],
        legend: {
          icon: 'circle',
          orient: 'vertical',
          right: 10,
          top: 'center',
          bottom: 20,
          textStyle: {
            color: '#fff'
          }
        },
        title: {
          left: 'center',
          textStyle: {
            color: '#fff'
          }
        },
        series: [
          {
            type: 'pie',
            radius: ['40%', '60%'],
            center: ['35%', '50%'],
            data: data.bridgeShapeType,
            label: {
              color: '#fff',
              formatter: a => {
                return `{percent|${a.percent}%}`
              },
              fontSize: 14,
              rich: {
                percent: {
                  fontSize: 15,
                  color: '#fff'
                }
              }
            },
            emphasis: {
              itemStyle: {
                shadowBlur: 10,
                shadowOffsetX: 0,
                shadowColor: 'rgba(0, 0, 0, 0.5)'
              }
            }
          }
        ]
      }
      option && myChart.setOption(option)
    }
  }
}
</script>

<style lang="scss" scoped>
* {
  margin: 0;
  padding: 0;
}
.content {
  height: 100vh;
}
/deep/ .el-form-item {
  margin-bottom: 0;
  padding: 10px;
}
.el-card_top {
  border-radius: 4px;
  border: 1px solid #113556;
  background-color: #103c5d !important;
  overflow: hidden;
  color: #303133;
  transition: 0.3s;
  box-shadow: 0 2px 12px #eee;
}
.top {
  display: flex;
  position: relative;
  height: 35px;
  margin-left: 40px;
  align-items: flex-end;
  background-image: linear-gradient(to right, #336da2, #1c3c60);
  p {
    position: absolute;
    left: -18px;
    top: -1px;
    width: 30px;
    height: 30px;
    display: flex;
    justify-content: center;
    align-items: center;
    border: 1px solid #6184ac;
    background-color: #304e7b;
    transform: rotate(45deg);
    border-radius: 5px;
    i {
      font-size: 25px;
      color: #91f5f3;
      transform: rotate(-45deg);
    }
  }
  h1 {
    margin-left: 25px;
    font-size: 16px;
    margin-bottom: 5px;
  }
}
.box-card {
  height: 320px;
  display: flex;
  margin-top: 10px;
  .item {
    flex: 1;
    height: 100%;
    position: relative;
  }
  .item-charts {
    margin-top: 10px;
    height: 100%;
    border: 1px solid #1a86af;
    border-radius: 10px;
  }
}
.table-box {
  margin-top: 10px;
  height: 100%;
  position: relative;
  .table-box-main {
    margin-top: 10px;
    height: calc(100% - 560px);
    border: 1px solid #1a86af;
    border-radius: 10px;
    overflow: hidden;
  }
  .botton {
    position: absolute;
    right: 0px;
		top: 0px;
		padding:  10px 15px;
  }
}
</style>
